@@ -1,9 +1,9 @@
 package Color::RGB::Util;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-01-19'; # DATE
+our $DATE = '2021-03-12'; # DATE
 our $DIST = 'Color-RGB-Util'; # DIST
-our $VERSION = '0.603'; # VERSION
+our $VERSION = '0.605'; # VERSION
 
 use 5.010001;
 use strict;
@@ -155,6 +155,7 @@ sub rand_rgb_colors {
     my $light_color  = exists($opts->{light_color}) ? $opts->{light_color} : 1;
     my $max_attempts = $opts->{max_attempts} // 1000;
     my $avoid_colors = $opts->{avoid_colors};
+    my $hash_prefix = $opts->{hash_prefix};
 
     my $num_check = 10;
     my $min_distance = rgb_diff("000000", "ffffff", "approx2") / 2 / $num;
@@ -189,7 +190,7 @@ sub rand_rgb_colors {
             last if !$reject;
             last if ++$num_attempts >= $max_attempts;
         }
-        push @res, $rgb;
+        push @res, ($hash_prefix ? "#" : "") . $rgb;
     }
     @res;
 }
@@ -524,7 +525,7 @@ Color::RGB::Util - Utilities related to RGB colors
 
 =head1 VERSION
 
-This document describes version 0.603 of Color::RGB::Util (from Perl distribution Color-RGB-Util), released on 2021-01-19.
+This document describes version 0.605 of Color::RGB::Util (from Perl distribution Color-RGB-Util), released on 2021-03-12.
 
 =head1 SYNOPSIS
 
@@ -613,6 +614,8 @@ Map a string to an RGB color. This is done by producing SHA-1 digest (160bit, 20
 bytes) of the string, then taking the first, 10th, and last byte to become the
 RGB color.
 
+See also: L</assign_rgb_dark_color> and L</assign_rgb_light_color>.
+
 =head2 assign_rgb_dark_color
 
 Like L</assign_rgb_color> except that it will make sure the assigned color is
@@ -631,6 +634,8 @@ Usage:
 
 Convert HSL to HSV.
 
+See also: L</hsv2hsl>.
+
 =head2 hsl2rgb
 
 Usage:
@@ -641,8 +646,9 @@ Convert HSL to RGB. HSL should be given in a whitespace-separated H,S,L values
 e.g. "0 1 0.5". H (hue degree) has a range from 0-360 where 0 is red, 120 is
 green, 240 is blue and 360 is back to red. S (saturation) has a range from 0-1
 where 0 is gray and 1 is fully saturated hue. L (lumination) has a range from
-0-1 where 0 is fully black, 0.5 fully saturated, and 1 is fully white. See also
-L</rgb2hsl>.
+0-1 where 0 is fully black, 0.5 fully saturated, and 1 is fully white.
+
+See also L</rgb2hsl>.
 
 =head2 hsv2hsl
 
@@ -652,6 +658,8 @@ Usage:
 
 Convert HSV to HSL.
 
+See also L</hsl2hsv>.
+
 =head2 hsv2rgb
 
 Usage:
@@ -662,7 +670,9 @@ Convert HSV to RGB. HSV should be given in a whitespace-separated H,S,V values
 e.g. "0 1 1". H (hue degree) has a range from 0-360 where 0 is red, 120 is
 green, 240 is blue and 360 is back to red. S (saturation) has a range from 0-1
 where 0 is gray and 1 is fully saturated hue. V (value) has a range from 0-1
-where 0 is black and 1 is white. See also L</rgb2hsv>.
+where 0 is black and 1 is white.
+
+See also L</rgb2hsv>.
 
 =head2 int2rgb
 
@@ -672,6 +682,8 @@ Usage:
 
 Convert integer to RGB string.
 
+See also L</rgb2int>.
+
 =head2 mix_2_rgb_colors
 
 Usage:
@@ -681,6 +693,8 @@ Usage:
 Mix 2 RGB colors. C<$pct> is a number between 0 and 1, by default 0.5 (halfway),
 the closer to 1 the closer the resulting color to C<$rgb2>.
 
+See also L</mix_rgb_colors>, L</tint_rgb_color>.
+
 =head2 mix_rgb_colors
 
 Usage:
@@ -689,6 +703,8 @@ Usage:
 
 Mix several RGB colors.
 
+See also L</mix_2_rgb_colors>.
+
 =head2 rand_rgb_color
 
 Usage:
@@ -698,6 +714,8 @@ Usage:
 Generate a random RGB color. You can specify the limit. Otherwise, they default
 to the full range (000000 to ffffff).
 
+See also L</rand_rgb_colors>.
+
 =head2 rand_rgb_colors
 
 Usage:
@@ -734,8 +752,15 @@ C<avoid_colors>.
 When the number of attempts has been exceeded, the generated color is used
 anyway.
 
+=item * hash_prefix
+
+Whether to add hash prefix to produced color codes ("#123456") or not
+("123456").
+
 =back
 
+See also L</rand_rgb_color>.
+
 =head2 reverse_rgb_color
 
 Usage:
@@ -752,6 +777,8 @@ Usage:
 
 Convert C<$rgb> to grayscale RGB value.
 
+See also L<rgb2sepia>.
+
 =head2 rgb2hsl
 
 Usage:
@@ -760,13 +787,17 @@ Usage:
 
 Convert RGB (0-255) to HSL. The result is a space-separated H, S, L values.
 
+See also L</hsl2rgb>.
+
 =head2 rgb2hsv
 
 Usage:
 
  my $hsv = rgb2hsv($rgb); # example: "0 1 255"
 
-Convert RGB (0-255) to HSV. The result is a space-separated H, S, V values. See
+Convert RGB (0-255) to HSV. The result is a space-separated H, S, V values.
+
+See also L</hsv2rgb>.
 
 =head2 rgb2int
 
@@ -776,6 +807,8 @@ Usage:
 
 Convert RGB string to integer.
 
+See also L</int2rgb>.
+
 =head2 rgb2sepia
 
 Usage:
@@ -784,6 +817,8 @@ Usage:
 
 Convert C<$rgb> to sepia tone RGB value.
 
+See also L<rgb2grayscale>.
+
 =head2 rgb_diff
 
 Usage:
@@ -842,6 +877,8 @@ L<https://en.wikipedia.org/wiki/Color_difference>.
 
 [1] https://www.compuphase.com/cmetric.htm
 
+See also L<rgb_distance>.
+
 =head2 rgb_distance
 
 Usage:
@@ -855,6 +892,8 @@ Calculate the euclidean RGB distance, using this formula:
 For example, the distance between "000000" and "ffffff" is ~441.67, while the
 distance between "ffff00" and "ffffff" is 255.
 
+See also L<rgb_diff>.
+
 =head2 rgb_is_dark
 
 Usage:
@@ -864,6 +903,8 @@ Usage:
 Return true if C<$rgb> is a "dark" color, which is determined by checking if the
 RGB distance to "000000" is smaller than to "ffffff".
 
+See also L</rgb_is_light>.
+
 =head2 rgb_is_light
 
 Usage:
@@ -873,6 +914,8 @@ Usage:
 Return true if C<$rgb> is a "light" color, which is determined by checking if
 the RGB distance to "000000" is larger than to "ffffff".
 
+See also L</rgb_is_dark>.
+
 =head2 rgb_luminance
 
 Usage:
@@ -895,6 +938,8 @@ Tint C<$rgb> with C<$tint_rgb>. $pct is by default 0.5. It is similar to mixing,
 but the less luminance the color is the less it is tinted with the tint color.
 This has the effect of black color still being black instead of becoming tinted.
 
+See also L<mix_2_rgb_colors>, L<mix_rgb_colors>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Color-RGB-Util>.
